﻿using System.ComponentModel;
using System.IO;
using System.Reflection;
using ff14bot.Enums;
using LlamaLibrary.JsonObjects;

namespace ZodiacWeapons.Settings;
[Obfuscation(Exclude=true, ApplyToMembers=true)]
public class ZodiacWeaponsSettings : JsonSettings<ZodiacWeaponsSettings>
{
    public ZodiacWeaponsSettings() : base(Path.Combine(CharacterSettingsDirectory, "ZodiacWeaponsSettings.json"))
    {
    }

    private static string _lightFarmDungeon;

    [DefaultValue("Bowl of Embers")]
    public string LightFarmDungeon
    {
        get => _lightFarmDungeon;
        set
        {
            if (_lightFarmDungeon != value)
            {
                _lightFarmDungeon = value;
                OnPropertyChanged();
            }
        }
    }

    private string _productKey;

    public string ProductKey
    {
        get => _productKey;
        set
        {
            if (value == _productKey)
            {
                return;
            }

            _productKey = value;
            OnPropertyChanged();
        }
    }

    private bool _debugMode;
    [DefaultValue(false)]
    public bool DebugEnabled
    {
        get => _debugMode;
        set
        {
            if (value == _debugMode)
            {
                return;
            }

            _debugMode = value;
            OnPropertyChanged();
        }
    }

    private bool _useFlight;
    [DefaultValue(true)]
    public bool UseFlight
    {
        get => _useFlight;
        set
        {
            if (value == _useFlight)
            {
                return;
            }

            _useFlight = value;
            OnPropertyChanged();
        }
    }

    private bool _enableDebugMode;
    public bool DebugMode
    {
        get => _enableDebugMode;
        set
        {
            if (value == _enableDebugMode)
            {
                return;
            }

            _enableDebugMode = value;
            OnPropertyChanged();
        }
    }

    private bool _runA9S;
    public bool RunA9S
    {
        get => _runA9S;
        set
        {
            if (value == _runA9S)
            {
                return;
            }

            _runA9S = value;
            OnPropertyChanged();
        }
    }

    private bool _trackAnimaBoolSetting;
    public bool TrackAnimaBoolSetting
    {
        get => _trackAnimaBoolSetting;
        set
        {
            if (value == _trackAnimaBoolSetting)
            {
                return;
            }

            _trackAnimaBoolSetting = value;
            OnPropertyChanged();
        }
    }

    private bool _trackHyperconductiveBoolSetting;
    public bool TrackHyperconductiveBoolSetting
    {
        get => _trackHyperconductiveBoolSetting;
        set
        {
            if (value == _trackHyperconductiveBoolSetting)
            {
                return;
            }

            _trackHyperconductiveBoolSetting = value;
            OnPropertyChanged();
        }
    }

    private bool _trackAnimatedBoolSetting;
    public bool TrackAnimatedBoolSetting
    {
        get => _trackAnimatedBoolSetting;
        set
        {
            if (value == _trackAnimatedBoolSetting)
            {
                return;
            }

            _trackAnimatedBoolSetting = value;
            OnPropertyChanged();
        }
    }

    private bool _trackReconditionedBoolSetting;
    public bool TrackReconditionedBoolSetting
    {
        get => _trackReconditionedBoolSetting;
        set
        {
            if (value == _trackReconditionedBoolSetting)
            {
                return;
            }

            _trackReconditionedBoolSetting = value;
            OnPropertyChanged();
        }
    }

    private bool _trackSharpenedBoolSetting;
    public bool TrackSharpenedBoolSetting
    {
        get => _trackSharpenedBoolSetting;
        set
        {
            if (value == _trackSharpenedBoolSetting)
            {
                return;
            }

            _trackSharpenedBoolSetting = value;
            OnPropertyChanged();
        }
    }

    private bool _barracksBoolSetting;
    public bool GoToBarracksBoolSetting
    {
        get => _barracksBoolSetting;
        set
        {
            if (value == _barracksBoolSetting)
            {
                return;
            }

            _barracksBoolSetting = value;
            OnPropertyChanged();
        }
    }

    private bool _gcTurnInEveryTimeBoolSetting;
    public bool GcTurnInEveryTimeBoolSetting
    {
        get => _gcTurnInEveryTimeBoolSetting;
        set
        {
            if (value == _gcTurnInEveryTimeBoolSetting)
            {
                return;
            }

            _gcTurnInEveryTimeBoolSetting = value;
            OnPropertyChanged();
        }
    }

    private bool _fateFarmBoolSetting;
    public bool FateFarmBoolSetting
    {
        get => _fateFarmBoolSetting;
        set
        {
            if (value == _fateFarmBoolSetting)
            {
                return;
            }

            _fateFarmBoolSetting = value;
            OnPropertyChanged();
        }
    }

    private static int _sphereScroll;
    [DefaultValue(7877)]
    public int SphereScrollChoice
    {
        get => _sphereScroll;
        set
        {
            if (_sphereScroll != value)
            {
                _sphereScroll = value;
                OnPropertyChanged();
            }
        }
    }

    private static int _astralQty;
    [DefaultValue(13)]
    public int AstralNoduleQty
    {
        get => _astralQty;
        set
        {
            if (_astralQty != value)
            {
                _astralQty = value;
                OnPropertyChanged();
            }
        }
    }

    private static int _umbralQty;
    [DefaultValue(13)]
    public int UmbralNoduleQty
    {
        get => _umbralQty;
        set
        {
            if (_umbralQty != value)
            {
                _umbralQty = value;
                OnPropertyChanged();
            }
        }
    }

    private static int _eRubberQty;
    [DefaultValue(13)]
    public int EnchantedRubberQty
    {
        get => _eRubberQty;
        set
        {
            if (_eRubberQty != value)
            {
                _eRubberQty = value;
                OnPropertyChanged();
            }
        }
    }

    private static int _fDCarboncoatQty;
    [DefaultValue(13)]
    public int FastdryingCarboncoatQty
    {
        get => _fDCarboncoatQty;
        set
        {
            if (_fDCarboncoatQty != value)
            {
                _fDCarboncoatQty = value;
                OnPropertyChanged();
            }
        }
    }

    private static int _dWaterQty;
    [DefaultValue(13)]
    public int DivineWaterQty
    {
        get => _dWaterQty;
        set
        {
            if (_dWaterQty != value)
            {
                _dWaterQty = value;
                OnPropertyChanged();
            }
        }
    }

    private static int _fAaCatalystQty;
    [DefaultValue(13)]
    public int FastactingAllaganCatalystQty
    {
        get => _fAaCatalystQty;
        set
        {
            if (_fAaCatalystQty != value)
            {
                _fAaCatalystQty = value;
                OnPropertyChanged();
            }
        }
    }

    private static int _aOilQty;
    [DefaultValue(65)]
    public int AetherOilQty
    {
        get => _aOilQty;
        set
        {
            if (_aOilQty != value)
            {
                _aOilQty = value;
                OnPropertyChanged();
            }
        }
    }

    private static int _cSandQty;
    [DefaultValue(780)]
    public int CrystalSandQty
    {
        get => _cSandQty;
        set
        {
            if (_cSandQty != value)
            {
                _cSandQty = value;
                OnPropertyChanged();
            }
        }
    }

    private static int _umbriteQty;
    [DefaultValue(780)]
    public int UmbriteQty
    {
        get => _umbriteQty;
        set
        {
            if (_umbriteQty != value)
            {
                _umbriteQty = value;
                OnPropertyChanged();
            }
        }
    }

    private static int _sClusterQty;
    [DefaultValue(650)]
    public int SingingClusterQty
    {
        get => _sClusterQty;
        set
        {
            if (_sClusterQty != value)
            {
                _sClusterQty = value;
                OnPropertyChanged();
            }
        }
    }

    private static ClassJobType _fateFarmClassChoice;
    [DefaultValue(ClassJobType.Adventurer)]
    public ClassJobType FateFarmClass
    {
        get => _fateFarmClassChoice;
        set
        {
            if (_fateFarmClassChoice != value)
            {
                _fateFarmClassChoice = value;
                OnPropertyChanged();
            }
        }
    }

    private static ClassJobType _relicClassChoice;
    [Description("Job to get relic for.")]
    [Category("Relic")]
    [DefaultValue(ClassJobType.Adventurer)]
    public ClassJobType RelicClassChoice
    {
        get => _relicClassChoice;
        set
        {
            if (_relicClassChoice != value)
            {
                _relicClassChoice = value;
                OnPropertyChanged();
            }
        }
    }

    private static ClassJobType _gcfarmJob;
    [Description("Job To use for farming Grand Comapny Seals.")]
    [Category("GC Farm")]
    [DefaultValue(ClassJobType.Adventurer)]
    public ClassJobType GCFarmClass
    {
        get => _gcfarmJob;
        set
        {
            if (_gcfarmJob != value)
            {
                _gcfarmJob = value;
                OnPropertyChanged();
            }
        }
    }

    private static ClassJobType _poeticsfarmJob;
    [Description("Job To use for farming Tomestone of Poetics.")]
    [Category("Poetics Farm")]
    [DefaultValue(ClassJobType.Adventurer)]
    public ClassJobType PoeticsFarmClass
    {
        get => _poeticsfarmJob;
        set
        {
            if (_poeticsfarmJob != value)
            {
                _poeticsfarmJob = value;
                OnPropertyChanged();
            }
        }
    }

}